@@ -17,13 +17,13 @@ from .templates import (
     GITKEEP_CONTENT,
     HEALTH_TESTCASE,
     HOOKS_TEMPLATE,
-    PERF_TESTCASE,
     SAMPLE_CURL,
     SAMPLE_HAR,
     SAMPLE_OPENAPI,
     SAMPLE_POSTMAN_COLLECTION,
     SAMPLE_POSTMAN_ENVIRONMENT,
     README_TEMPLATE,
+    STREAM_TESTCASE,
 )
 
 __all__ = [
@@ -39,11 +39,11 @@ __all__ = [
     "GITKEEP_CONTENT",
     "HEALTH_TESTCASE",
     "HOOKS_TEMPLATE",
-    "PERF_TESTCASE",
     "README_TEMPLATE",
     "SAMPLE_CURL",
     "SAMPLE_HAR",
     "SAMPLE_OPENAPI",
     "SAMPLE_POSTMAN_COLLECTION",
     "SAMPLE_POSTMAN_ENVIRONMENT",
+    "STREAM_TESTCASE",
 ]
